# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.10.5
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class OpenIDConnectConfiguration(BaseModel):
    """
    rest_framework Serializer for OIDC Configuration
    """ # noqa: E501
    issuer: StrictStr
    authorization_endpoint: StrictStr
    token_endpoint: StrictStr
    userinfo_endpoint: StrictStr
    end_session_endpoint: StrictStr
    introspection_endpoint: StrictStr
    jwks_uri: StrictStr
    response_types_supported: List[StrictStr]
    id_token_signing_alg_values_supported: List[StrictStr]
    subject_types_supported: List[StrictStr]
    token_endpoint_auth_methods_supported: List[StrictStr]
    __properties: ClassVar[List[str]] = ["issuer", "authorization_endpoint", "token_endpoint", "userinfo_endpoint", "end_session_endpoint", "introspection_endpoint", "jwks_uri", "response_types_supported", "id_token_signing_alg_values_supported", "subject_types_supported", "token_endpoint_auth_methods_supported"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OpenIDConnectConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OpenIDConnectConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "issuer": obj.get("issuer"),
            "authorization_endpoint": obj.get("authorization_endpoint"),
            "token_endpoint": obj.get("token_endpoint"),
            "userinfo_endpoint": obj.get("userinfo_endpoint"),
            "end_session_endpoint": obj.get("end_session_endpoint"),
            "introspection_endpoint": obj.get("introspection_endpoint"),
            "jwks_uri": obj.get("jwks_uri"),
            "response_types_supported": obj.get("response_types_supported"),
            "id_token_signing_alg_values_supported": obj.get("id_token_signing_alg_values_supported"),
            "subject_types_supported": obj.get("subject_types_supported"),
            "token_endpoint_auth_methods_supported": obj.get("token_endpoint_auth_methods_supported")
        })
        return _obj


